@@ -1,6 +1,6 @@
 /*
  * This file is part of Gnome Subtitles.
- * Copyright (C) 2006-2010 Pedro Castro
+ * Copyright (C) 2006-2011 Pedro Castro
  *
  * Gnome Subtitles is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,9 +21,11 @@ using GnomeSubtitles.Core.Command;
 using GnomeSubtitles.Dialog;
 using GnomeSubtitles.Dialog.Unmanaged;
 using GnomeSubtitles.Ui;
+using GnomeSubtitles.Ui.View;
 using Gtk;
 using Mono.Unix;
 using SubLib.Core.Domain;
+using SubLib.Core.Timing;
 using System;
 using System.Text;
 
@@ -32,10 +34,11 @@ namespace GnomeSubtitles.Core {
 public class EventHandlers {
 	private bool buttonStartEndKeyPressed = false; //Used to match grab focus and key release events
 	
+
 	/* File Menu */
 	
 	public void OnFileNew (object o, EventArgs args) {
-		Base.Ui.New(String.Empty);
+		Base.Ui.New();
 	}
 	
 	public void OnFileOpen (object o, EventArgs args) {
@@ -132,15 +135,32 @@ public class EventHandlers {
 		Base.CommandManager.Execute(new ChangeUnderlineStyleCommand(newUnderlineValue));
 	}
 	
+	public void OnEditSplit (object o, EventArgs args) {
+		Base.CommandManager.Execute(new SplitSubtitlesCommand());
+	}
+	
+	public void OnEditMerge (object o, EventArgs args) {
+		Base.CommandManager.Execute(new MergeSubtitlesCommand());
+	}
+	
 	public void OnEditInsertSubtitleBefore (object o, EventArgs args) {
-		Base.CommandManager.Execute(new InsertSubtitleBeforeCommand());
+		if ((Base.Document.Subtitles.Count == 0) || (Base.Ui.View.Selection.Count == 0))
+			Base.CommandManager.Execute(new InsertFirstSubtitleCommand());
+		else 
+			Base.CommandManager.Execute(new InsertSubtitleBeforeCommand());
 	}
 	
 	public void OnEditInsertSubtitleAfter (object o, EventArgs args) {
 		if (Base.Document.Subtitles.Count == 0)
 			Base.CommandManager.Execute(new InsertFirstSubtitleCommand());
-		else
+		else if (Base.Ui.View.Selection.Count > 0)
 			Base.CommandManager.Execute(new InsertSubtitleAfterCommand());
+		else
+			Base.CommandManager.Execute(new InsertLastSubtitleCommand());
+	}
+	
+	public void OnEditInsertSubtitleAtVideoPosition (object o, EventArgs args) {
+		Base.CommandManager.Execute(new InsertSubtitleAtVideoPositionCommand());
 	}
 	
 	public void OnEditDeleteSubtitles (object o, EventArgs args) {
@@ -164,14 +184,18 @@ public class EventHandlers {
 		if ((o as RadioMenuItem).Active)
 			Base.TimingMode = TimingMode.Frames;
 	}
+			
+	public void OnViewLineLengthsToggled (object o, EventArgs args) {
+		CheckMenuItem menuItem = o as CheckMenuItem;
+		Base.Config.PrefsViewLineLengths = menuItem.Active;
+	}
 	
 	public void OnViewVideo (object o, EventArgs args) {
 		if ((o as CheckMenuItem).Active)
 			Base.Ui.Video.Show();
 		else
 			Base.Ui.Video.Hide();
-	}
-	
+	}	
 		
 	public void OnViewVideoSubtitlesText (object o, EventArgs args) {
 		if ((o as RadioMenuItem).Active)
@@ -205,22 +229,6 @@ public class EventHandlers {
 
 	/*	Timings Menu */
 	
-	public void OnTimingsInputFrameRate (object o, EventArgs args) {
-		RadioMenuItem menuItem = o as RadioMenuItem;
-		if (menuItem.Active) {
-			float frameRate = Menus.FrameRateFromMenuItem((menuItem.Child as Label).Text);
-			Base.CommandManager.Execute(new ChangeInputFrameRateCommand(frameRate));
-		}
-	}
-	
-	public void OnTimingsVideoFrameRate (object o, EventArgs args) {
-		RadioMenuItem menuItem = o as RadioMenuItem;
-		if (menuItem.Active) {
-			float frameRate = Menus.FrameRateFromMenuItem((menuItem.Child as Label).Text);
-			Base.CommandManager.Execute(new ChangeVideoFrameRateCommand(frameRate));
-		}
-	}
-	
 	public void OnTimingsAdjust (object o, EventArgs args) {
 		Base.Dialogs.Get(typeof(TimingsAdjustDialog)).Show();
 	}
@@ -257,6 +265,18 @@ public class EventHandlers {
 		Base.Ui.Video.Forward();
 	}
 	
+	public void OnVideoSpeedUp (object o, EventArgs args) {
+	    Base.Ui.Video.SpeedUp();
+	} 
+	
+	public void OnVideoSpeedDown (object o, EventArgs args) {
+	    Base.Ui.Video.SpeedDown();
+	}
+	
+	public void OnVideoSpeed (object o, EventArgs args) {
+	    Base.Ui.Video.SpeedReset();
+	} 
+	
 	public void OnVideoSeekTo (object o, EventArgs args) {
 		Base.Dialogs.Get(typeof(VideoSeekToDialog)).Show();
 	}
@@ -281,10 +301,16 @@ public class EventHandlers {
 	public void OnVideoSetSubtitleStart (object o, EventArgs args) {
 		if (Base.TimingMode == TimingMode.Times) {
 			TimeSpan time = Base.Ui.Video.Position.CurrentTime;
+			if (Base.Ui.Video.IsStatePlaying && Base.Config.PrefsVideoApplyReactionDelay) {
+				time -= TimeSpan.FromMilliseconds(Base.Config.PrefsVideoReactionDelay);
+			}
 			Base.CommandManager.Execute(new VideoSetSubtitleStartCommand(time));
 		}
 		else {
 			int frames = Base.Ui.Video.Position.CurrentFrames;
+			if (Base.Ui.Video.IsStatePlaying && Base.Config.PrefsVideoApplyReactionDelay) {
+				frames -= (int)TimingUtil.TimeMillisecondsToFrames(Base.Config.PrefsVideoReactionDelay, Base.Ui.Video.FrameRate);
+			}
 			Base.CommandManager.Execute(new VideoSetSubtitleStartCommand(frames));
 		}			
 	}
@@ -292,10 +318,16 @@ public class EventHandlers {
 	public void OnVideoSetSubtitleEnd (object o, EventArgs args) {
 		if (Base.TimingMode == TimingMode.Times) {
 			TimeSpan time = Base.Ui.Video.Position.CurrentTime;
+			if (Base.Ui.Video.IsStatePlaying && Base.Config.PrefsVideoApplyReactionDelay) {
+				time -= TimeSpan.FromMilliseconds(Base.Config.PrefsVideoReactionDelay);
+			}
 			Base.CommandManager.Execute(new VideoSetSubtitleEndCommand(time));
 		}
 		else {
 			int frames = Base.Ui.Video.Position.CurrentFrames;
+			if (Base.Ui.Video.IsStatePlaying && Base.Config.PrefsVideoApplyReactionDelay) {
+				frames -= (int)TimingUtil.TimeMillisecondsToFrames(Base.Config.PrefsVideoReactionDelay, Base.Ui.Video.FrameRate);
+			}
 			Base.CommandManager.Execute(new VideoSetSubtitleEndCommand(frames));
 		}
 	}
@@ -303,11 +335,17 @@ public class EventHandlers {
 	public void OnVideoSetSubtitleStartEnd (object o, EventArgs args) {
 		if (Base.TimingMode == TimingMode.Times) {
 			TimeSpan time = Base.Ui.Video.Position.CurrentTime;
+			if (Base.Ui.Video.IsStatePlaying && Base.Config.PrefsVideoApplyReactionDelay) {
+				time -= TimeSpan.FromMilliseconds(Base.Config.PrefsVideoReactionDelay);
+			}
 			Base.CommandManager.Execute(new VideoSetSubtitleEndCommand(time));
 			Base.Ui.View.SelectNextSubtitle();
 		}
 		else {
 			int frames = Base.Ui.Video.Position.CurrentFrames;
+			if (Base.Ui.Video.IsStatePlaying && Base.Config.PrefsVideoApplyReactionDelay) {
+				frames -= (int)TimingUtil.TimeMillisecondsToFrames(Base.Config.PrefsVideoReactionDelay, Base.Ui.Video.FrameRate);
+			}
 			Base.CommandManager.Execute(new VideoSetSubtitleEndCommand(frames));
 			Base.Ui.View.SelectNextSubtitle();
 		}
@@ -341,6 +379,14 @@ public class EventHandlers {
 	public void OnToolsSetTranslationLanguage (object o, EventArgs args) {
 		Base.Dialogs.Get(typeof(SetTranslationLanguageDialog)).Show();
 	}
+		
+	public void OnToolsTranslateText (object o, EventArgs args) {
+		Base.CommandManager.Execute(new TranslatorCommand(true));
+	}
+		
+	public void OnToolsTranslateTranslation (object o, EventArgs args) {
+		Base.CommandManager.Execute(new TranslatorCommand(false));	
+	}
 	
 	
 	/*	Help Menu */
@@ -354,7 +400,7 @@ public class EventHandlers {
 	}
 	
 	public void OnHelpKeyboardShortcuts (object o, EventArgs args) {
-		Util.OpenUrl("http://live.gnome.org/GnomeSubtitles/KeyboardShortcuts");
+		Util.OpenUrl("http://gnome-subtitles.sourceforge.net/shortcuts");
 	}
 
 	public void OnHelpRequestFeature (object o, EventArgs args) {
@@ -428,6 +474,81 @@ public class EventHandlers {
 
 		Gtk.Drag.Finish(args.Context, success, false, args.Time);
 	}
+	
+	
+	/* Global Accelerators */
+
+	public void OnGlobalSubtitleStartIncrease (object o, EventArgs args) {
+		if (Base.Ui.View.Selection.Count == 1) {
+			Base.Ui.Edit.SpinButtons.StartSpinButtonIncreaseStep();
+		}
+	}
+	
+	public void OnGlobalSubtitleStartDecrease (object o, EventArgs args) {
+		/* Do nothing if there isn't only 1 subtitle selected */
+		if (Base.Ui.View.Selection.Count != 1)
+			return;
+		
+		Subtitle subtitle = Base.Ui.View.Selection.Subtitle;
+		if ((Base.TimingModeIsTimes && (subtitle.Times.Start >= TimeSpan.FromMilliseconds(Base.Config.PrefsTimingsTimeStep)))
+				|| (!Base.TimingModeIsTimes) && (subtitle.Frames.Start >= Base.Config.PrefsTimingsFramesStep)){
+
+			Base.Ui.Edit.SpinButtons.StartSpinButtonDecreaseStep();
+		}
+	}
+	
+	public void OnGlobalSubtitleEndIncrease (object o, EventArgs args) {
+		if (Base.Ui.View.Selection.Count == 1) {
+			Base.Ui.Edit.SpinButtons.EndSpinButtonIncreaseStep();
+		}
+	}
+	
+	public void OnGlobalSubtitleEndDecrease (object o, EventArgs args) {
+		/* Do nothing if there isn't only 1 subtitle selected */
+		if (Base.Ui.View.Selection.Count != 1)
+			return;
+		
+		Subtitle subtitle = Base.Ui.View.Selection.Subtitle;
+		if ((Base.TimingModeIsTimes && (subtitle.Times.End >= TimeSpan.FromMilliseconds(Base.Config.PrefsTimingsTimeStep)))
+				|| (!Base.TimingModeIsTimes) && (subtitle.Frames.End >= Base.Config.PrefsTimingsFramesStep)){
+
+			Base.Ui.Edit.SpinButtons.EndSpinButtonDecreaseStep();
+		}
+	}
+	
+	public void OnGlobalSelectionShiftIncrease (object o, EventArgs args) {
+		/* Do nothing if no subtitles are selected */
+		if (Base.Ui.View.Selection.Count == 0)
+			return;
+		
+		if (Base.TimingModeIsTimes) {
+			Base.CommandManager.Execute(new ShiftTimingsCommand(TimeSpan.FromMilliseconds(Base.Config.PrefsTimingsTimeStep), SelectionIntended.Simple));
+		}
+		else {
+			Base.CommandManager.Execute(new ShiftTimingsCommand(Base.Config.PrefsTimingsFramesStep, SelectionIntended.Simple));
+		}
+	}
+	
+	public void OnGlobalSelectionShiftDecrease (object o, EventArgs args) {
+		Subtitle firstSelectedSubtitle = Base.Ui.View.Selection.FirstSubtitle;
+		
+		/* Do nothing if no subtitles are selected */
+		if (firstSelectedSubtitle == null)
+			return;
+		
+		if (Base.TimingModeIsTimes) {
+			TimeSpan timeStep = TimeSpan.FromMilliseconds(Base.Config.PrefsTimingsTimeStep);
+			if (firstSelectedSubtitle.Times.Start >= timeStep) {
+				Base.CommandManager.Execute(new ShiftTimingsCommand(timeStep.Negate(), SelectionIntended.Simple));
+			}
+		}
+		else {
+			int framesStep = Base.Config.PrefsTimingsFramesStep;
+			if (firstSelectedSubtitle.Frames.Start >= framesStep) {
+				Base.CommandManager.Execute(new ShiftTimingsCommand(-framesStep, SelectionIntended.Simple));
+			}
+		}
+	}
 
 }
 
