@@ -1,6 +1,6 @@
 /*
  * This file is part of SubLib.
- * Copyright (C) 2005-2010 Pedro Castro
+ * Copyright (C) 2005-2011 Pedro Castro
  *
  * SubLib is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -54,11 +54,19 @@ public class SubtitleText : ICloneable {
 	
 	/// <summary>Whether there is no text.</summary>
 	public bool IsEmpty {
-		get { return (lines.Count == 0); }
+		get { return ((lines.Count == 0) || ((lines.Count == 1) && ((lines[0] as string).Length == 0))); }
+	}
+		
+	public IEnumerator GetEnumerator () {
+		return lines.GetEnumerator();
 	}
 
 	
 	/* Public methods */
+	
+	public void Clear () {
+		lines.Clear();
+	}
 
 	/// <summary>Gets the specified text line.</summary>
 	/// <param name="index">The zero-based line number index.</param>
@@ -153,6 +161,10 @@ public class SubtitleText : ICloneable {
 		return GetTrimLines("\n");
 	}
 	
+	public string[] GetLines () {
+		return (string[])lines.ToArray(typeof(String));
+	}
+	
 	/// <summary>Sets the subtitle text using the specified line break and trimming option.</summary>
 	/// <param name="text">The subtitle text.</param>
 	/// <param name="lineBreak">The text substring used to split the text in lines.</param>
@@ -165,7 +177,7 @@ public class SubtitleText : ICloneable {
 		string spaceDelimiter = (toTrimLines ? @"\s*" : String.Empty);
 		string regexPattern = spaceDelimiter + @escapedLineBreak + spaceDelimiter;
 		string[] textLines = Regex.Split(text, regexPattern);
-		lines.Clear();
+		Clear();
 		foreach (string textLine in textLines)
 			lines.Add(textLine);
 	}
@@ -177,6 +189,19 @@ public class SubtitleText : ICloneable {
 		Set(text, "\n", false);
 	}
 	
+	public void Set (string[] newLines) {
+		Clear();
+		Add(newLines);
+	}
+	
+	public void Add (string[] newLines) {
+		foreach (string newLine in newLines) {
+			string trimmedLine = newLine.Trim();
+			if (trimmedLine != String.Empty)
+				lines.Add(trimmedLine);
+		}
+	}
+	
 	public override string ToString() {
 		string result = String.Empty;
 	  	int lineNumber = 1;
